package tlsmap

import "fmt"

var cipherSuites = map[uint16]string{
	0x0000: "TLS NULL WITH NULL NULL",
	0x0001: "TLS RSA WITH NULL MD5",
	0x0002: "TLS RSA WITH NULL SHA",
	0x0003: "TLS RSA EXPORT WITH RC4 40 MD5",
	0x0004: "TLS RSA WITH RC4 128 MD5",
	0x0005: "TLS RSA WITH RC4 128 SHA",
	0x0006: "TLS RSA EXPORT WITH RC2 CBC 40 MD5",
	0x0007: "TLS RSA WITH IDEA CBC SHA",
	0x0008: "TLS RSA EXPORT WITH DES40 CBC SHA",
	0x0009: "TLS RSA WITH DES CBC SHA",
	0x000A: "TLS RSA WITH 3DES EDE CBC SHA",
	0x000B: "TLS DH DSS EXPORT WITH DES40 CBC SHA",
	0x000C: "TLS DH DSS WITH DES CBC SHA",
	0x000D: "TLS DH DSS WITH 3DES EDE CBC SHA",
	0x000E: "TLS DH RSA EXPORT WITH DES40 CBC SHA",
	0x000F: "TLS DH RSA WITH DES CBC SHA",
	0x0010: "TLS DH RSA WITH 3DES EDE CBC SHA",
	0x0011: "TLS DHE DSS EXPORT WITH DES40 CBC SHA",
	0x0012: "TLS DHE DSS WITH DES CBC SHA",
	0x0013: "TLS DHE DSS WITH 3DES EDE CBC SHA",
	0x0014: "TLS DHE RSA EXPORT WITH DES40 CBC SHA",
	0x0015: "TLS DHE RSA WITH DES CBC SHA",
	0x0016: "TLS DHE RSA WITH 3DES EDE CBC SHA",
	0x0017: "TLS DH anon EXPORT WITH RC4 40 MD5",
	0x0018: "TLS DH anon WITH RC4 128 MD5",
	0x0019: "TLS DH anon EXPORT WITH DES40 CBC SHA",
	0x001A: "TLS DH anon WITH DES CBC SHA",
	0x001B: "TLS DH anon WITH 3DES EDE CBC SHA",
	0x001E: "TLS KRB5 WITH DES CBC SHA",
	0x001F: "TLS KRB5 WITH 3DES EDE CBC SHA",
	0x0020: "TLS KRB5 WITH RC4 128 SHA",
	0x0021: "TLS KRB5 WITH IDEA CBC SHA",
	0x0022: "TLS KRB5 WITH DES CBC MD5",
	0x0023: "TLS KRB5 WITH 3DES EDE CBC MD5",
	0x0024: "TLS KRB5 WITH RC4 128 MD5",
	0x0025: "TLS KRB5 WITH IDEA CBC MD5",
	0x0026: "TLS KRB5 EXPORT WITH DES CBC 40 SHA",
	0x0027: "TLS KRB5 EXPORT WITH RC2 CBC 40 SHA",
	0x0028: "TLS KRB5 EXPORT WITH RC4 40 SHA",
	0x0029: "TLS KRB5 EXPORT WITH DES CBC 40 MD5",
	0x002A: "TLS KRB5 EXPORT WITH RC2 CBC 40 MD5",
	0x002B: "TLS KRB5 EXPORT WITH RC4 40 MD5",
	0x002C: "TLS PSK WITH NULL SHA",
	0x002D: "TLS DHE PSK WITH NULL SHA",
	0x002E: "TLS RSA PSK WITH NULL SHA",
	0x002F: "TLS RSA WITH AES 128 CBC SHA",
	0x0030: "TLS DH DSS WITH AES 128 CBC SHA",
	0x0031: "TLS DH RSA WITH AES 128 CBC SHA",
	0x0032: "TLS DHE DSS WITH AES 128 CBC SHA",
	0x0033: "TLS DHE RSA WITH AES 128 CBC SHA",
	0x0034: "TLS DH anon WITH AES 128 CBC SHA",
	0x0035: "TLS RSA WITH AES 256 CBC SHA",
	0x0036: "TLS DH DSS WITH AES 256 CBC SHA",
	0x0037: "TLS DH RSA WITH AES 256 CBC SHA",
	0x0038: "TLS DHE DSS WITH AES 256 CBC SHA",
	0x0039: "TLS DHE RSA WITH AES 256 CBC SHA",
	0x003A: "TLS DH anon WITH AES 256 CBC SHA",
	0x003B: "TLS RSA WITH NULL SHA256",
	0x003C: "TLS RSA WITH AES 128 CBC SHA256",
	0x003D: "TLS RSA WITH AES 256 CBC SHA256",
	0x003E: "TLS DH DSS WITH AES 128 CBC SHA256",
	0x003F: "TLS DH RSA WITH AES 128 CBC SHA256",
	0x0040: "TLS DHE DSS WITH AES 128 CBC SHA256",
	0x0041: "TLS RSA WITH CAMELLIA 128 CBC SHA",
	0x0042: "TLS DH DSS WITH CAMELLIA 128 CBC SHA",
	0x0043: "TLS DH RSA WITH CAMELLIA 128 CBC SHA",
	0x0044: "TLS DHE DSS WITH CAMELLIA 128 CBC SHA",
	0x0045: "TLS DHE RSA WITH CAMELLIA 128 CBC SHA",
	0x0046: "TLS DH anon WITH CAMELLIA 128 CBC SHA",
	0x0067: "TLS DHE RSA WITH AES 128 CBC SHA256",
	0x0068: "TLS DH DSS WITH AES 256 CBC SHA256",
	0x0069: "TLS DH RSA WITH AES 256 CBC SHA256",
	0x006A: "TLS DHE DSS WITH AES 256 CBC SHA256",
	0x006B: "TLS DHE RSA WITH AES 256 CBC SHA256",
	0x006C: "TLS DH anon WITH AES 128 CBC SHA256",
	0x006D: "TLS DH anon WITH AES 256 CBC SHA256",
	0x0084: "TLS RSA WITH CAMELLIA 256 CBC SHA",
	0x0085: "TLS DH DSS WITH CAMELLIA 256 CBC SHA",
	0x0086: "TLS DH RSA WITH CAMELLIA 256 CBC SHA",
	0x0087: "TLS DHE DSS WITH CAMELLIA 256 CBC SHA",
	0x0088: "TLS DHE RSA WITH CAMELLIA 256 CBC SHA",
	0x0089: "TLS DH anon WITH CAMELLIA 256 CBC SHA",
	0x008A: "TLS PSK WITH RC4 128 SHA",
	0x008B: "TLS PSK WITH 3DES EDE CBC SHA",
	0x008C: "TLS PSK WITH AES 128 CBC SHA",
	0x008D: "TLS PSK WITH AES 256 CBC SHA",
	0x008E: "TLS DHE PSK WITH RC4 128 SHA",
	0x008F: "TLS DHE PSK WITH 3DES EDE CBC SHA",
	0x0090: "TLS DHE PSK WITH AES 128 CBC SHA",
	0x0091: "TLS DHE PSK WITH AES 256 CBC SHA",
	0x0092: "TLS RSA PSK WITH RC4 128 SHA",
	0x0093: "TLS RSA PSK WITH 3DES EDE CBC SHA",
	0x0094: "TLS RSA PSK WITH AES 128 CBC SHA",
	0x0095: "TLS RSA PSK WITH AES 256 CBC SHA",
	0x0096: "TLS RSA WITH SEED CBC SHA",
	0x0097: "TLS DH DSS WITH SEED CBC SHA",
	0x0098: "TLS DH RSA WITH SEED CBC SHA",
	0x0099: "TLS DHE DSS WITH SEED CBC SHA",
	0x009A: "TLS DHE RSA WITH SEED CBC SHA",
	0x009B: "TLS DH anon WITH SEED CBC SHA",
	0x009C: "TLS RSA WITH AES 128 GCM SHA256",
	0x009D: "TLS RSA WITH AES 256 GCM SHA384",
	0x009E: "TLS DHE RSA WITH AES 128 GCM SHA256",
	0x009F: "TLS DHE RSA WITH AES 256 GCM SHA384",
	0x00A0: "TLS DH RSA WITH AES 128 GCM SHA256",
	0x00A1: "TLS DH RSA WITH AES 256 GCM SHA384",
	0x00A2: "TLS DHE DSS WITH AES 128 GCM SHA256",
	0x00A3: "TLS DHE DSS WITH AES 256 GCM SHA384",
	0x00A4: "TLS DH DSS WITH AES 128 GCM SHA256",
	0x00A5: "TLS DH DSS WITH AES 256 GCM SHA384",
	0x00A6: "TLS DH anon WITH AES 128 GCM SHA256",
	0x00A7: "TLS DH anon WITH AES 256 GCM SHA384",
	0x00A8: "TLS PSK WITH AES 128 GCM SHA256",
	0x00A9: "TLS PSK WITH AES 256 GCM SHA384",
	0x00AA: "TLS DHE PSK WITH AES 128 GCM SHA256",
	0x00AB: "TLS DHE PSK WITH AES 256 GCM SHA384",
	0x00AC: "TLS RSA PSK WITH AES 128 GCM SHA256",
	0x00AD: "TLS RSA PSK WITH AES 256 GCM SHA384",
	0x00AE: "TLS PSK WITH AES 128 CBC SHA256",
	0x00AF: "TLS PSK WITH AES 256 CBC SHA384",
	0x00B0: "TLS PSK WITH NULL SHA256",
	0x00B1: "TLS PSK WITH NULL SHA384",
	0x00B2: "TLS DHE PSK WITH AES 128 CBC SHA256",
	0x00B3: "TLS DHE PSK WITH AES 256 CBC SHA384",
	0x00B4: "TLS DHE PSK WITH NULL SHA256",
	0x00B5: "TLS DHE PSK WITH NULL SHA384",
	0x00B6: "TLS RSA PSK WITH AES 128 CBC SHA256",
	0x00B7: "TLS RSA PSK WITH AES 256 CBC SHA384",
	0x00B8: "TLS RSA PSK WITH NULL SHA256",
	0x00B9: "TLS RSA PSK WITH NULL SHA384",
	0x00BA: "TLS RSA WITH CAMELLIA 128 CBC SHA256",
	0x00BB: "TLS DH DSS WITH CAMELLIA 128 CBC SHA256",
	0x00BC: "TLS DH RSA WITH CAMELLIA 128 CBC SHA256",
	0x00BD: "TLS DHE DSS WITH CAMELLIA 128 CBC SHA256",
	0x00BE: "TLS DHE RSA WITH CAMELLIA 128 CBC SHA256",
	0x00BF: "TLS DH anon WITH CAMELLIA 128 CBC SHA256",
	0x00C0: "TLS RSA WITH CAMELLIA 256 CBC SHA256",
	0x00C1: "TLS DH DSS WITH CAMELLIA 256 CBC SHA256",
	0x00C2: "TLS DH RSA WITH CAMELLIA 256 CBC SHA256",
	0x00C3: "TLS DHE DSS WITH CAMELLIA 256 CBC SHA256",
	0x00C4: "TLS DHE RSA WITH CAMELLIA 256 CBC SHA256",
	0x00C5: "TLS DH anon WITH CAMELLIA 256 CBC SHA256",
	0x00C6: "TLS SM4 GCM SM3",
	0x00C7: "TLS SM4 CCM SM3",
	0x00FF: "TLS EMPTY RENEGOTIATION INFO SCSV",
	0x1301: "TLS AES 128 GCM SHA256",
	0x1302: "TLS AES 256 GCM SHA384",
	0x1303: "TLS CHACHA20 POLY1305 SHA256",
	0x1304: "TLS AES 128 CCM SHA256",
	0x1305: "TLS AES 128 CCM 8 SHA256",
	0x5600: "TLS FALLBACK SCSV",
	0xC001: "TLS ECDH ECDSA WITH NULL SHA",
	0xC002: "TLS ECDH ECDSA WITH RC4 128 SHA",
	0xC003: "TLS ECDH ECDSA WITH 3DES EDE CBC SHA",
	0xC004: "TLS ECDH ECDSA WITH AES 128 CBC SHA",
	0xC005: "TLS ECDH ECDSA WITH AES 256 CBC SHA",
	0xC006: "TLS ECDHE ECDSA WITH NULL SHA",
	0xC007: "TLS ECDHE ECDSA WITH RC4 128 SHA",
	0xC008: "TLS ECDHE ECDSA WITH 3DES EDE CBC SHA",
	0xC009: "TLS ECDHE ECDSA WITH AES 128 CBC SHA",
	0xC00A: "TLS ECDHE ECDSA WITH AES 256 CBC SHA",
	0xC00B: "TLS ECDH RSA WITH NULL SHA",
	0xC00C: "TLS ECDH RSA WITH RC4 128 SHA",
	0xC00D: "TLS ECDH RSA WITH 3DES EDE CBC SHA",
	0xC00E: "TLS ECDH RSA WITH AES 128 CBC SHA",
	0xC00F: "TLS ECDH RSA WITH AES 256 CBC SHA",
	0xC010: "TLS ECDHE RSA WITH NULL SHA",
	0xC011: "TLS ECDHE RSA WITH RC4 128 SHA",
	0xC012: "TLS ECDHE RSA WITH 3DES EDE CBC SHA",
	0xC013: "TLS ECDHE RSA WITH AES 128 CBC SHA",
	0xC014: "TLS ECDHE RSA WITH AES 256 CBC SHA",
	0xC015: "TLS ECDH anon WITH NULL SHA",
	0xC016: "TLS ECDH anon WITH RC4 128 SHA",
	0xC017: "TLS ECDH anon WITH 3DES EDE CBC SHA",
	0xC018: "TLS ECDH anon WITH AES 128 CBC SHA",
	0xC019: "TLS ECDH anon WITH AES 256 CBC SHA",
	0xC01A: "TLS SRP SHA WITH 3DES EDE CBC SHA",
	0xC01B: "TLS SRP SHA RSA WITH 3DES EDE CBC SHA",
	0xC01C: "TLS SRP SHA DSS WITH 3DES EDE CBC SHA",
	0xC01D: "TLS SRP SHA WITH AES 128 CBC SHA",
	0xC01E: "TLS SRP SHA RSA WITH AES 128 CBC SHA",
	0xC01F: "TLS SRP SHA DSS WITH AES 128 CBC SHA",
	0xC020: "TLS SRP SHA WITH AES 256 CBC SHA",
	0xC021: "TLS SRP SHA RSA WITH AES 256 CBC SHA",
	0xC022: "TLS SRP SHA DSS WITH AES 256 CBC SHA",
	0xC023: "TLS ECDHE ECDSA WITH AES 128 CBC SHA256",
	0xC024: "TLS ECDHE ECDSA WITH AES 256 CBC SHA384",
	0xC025: "TLS ECDH ECDSA WITH AES 128 CBC SHA256",
	0xC026: "TLS ECDH ECDSA WITH AES 256 CBC SHA384",
	0xC027: "TLS ECDHE RSA WITH AES 128 CBC SHA256",
	0xC028: "TLS ECDHE RSA WITH AES 256 CBC SHA384",
	0xC029: "TLS ECDH RSA WITH AES 128 CBC SHA256",
	0xC02A: "TLS ECDH RSA WITH AES 256 CBC SHA384",
	0xC02B: "TLS ECDHE ECDSA WITH AES 128 GCM SHA256",
	0xC02C: "TLS ECDHE ECDSA WITH AES 256 GCM SHA384",
	0xC02D: "TLS ECDH ECDSA WITH AES 128 GCM SHA256",
	0xC02E: "TLS ECDH ECDSA WITH AES 256 GCM SHA384",
	0xC02F: "TLS ECDHE RSA WITH AES 128 GCM SHA256",
	0xC030: "TLS ECDHE RSA WITH AES 256 GCM SHA384",
	0xC031: "TLS ECDH RSA WITH AES 128 GCM SHA256",
	0xC032: "TLS ECDH RSA WITH AES 256 GCM SHA384",
	0xC033: "TLS ECDHE PSK WITH RC4 128 SHA",
	0xC034: "TLS ECDHE PSK WITH 3DES EDE CBC SHA",
	0xC035: "TLS ECDHE PSK WITH AES 128 CBC SHA",
	0xC036: "TLS ECDHE PSK WITH AES 256 CBC SHA",
	0xC037: "TLS ECDHE PSK WITH AES 128 CBC SHA256",
	0xC038: "TLS ECDHE PSK WITH AES 256 CBC SHA384",
	0xC039: "TLS ECDHE PSK WITH NULL SHA",
	0xC03A: "TLS ECDHE PSK WITH NULL SHA256",
	0xC03B: "TLS ECDHE PSK WITH NULL SHA384",
	0xC03C: "TLS RSA WITH ARIA 128 CBC SHA256",
	0xC03D: "TLS RSA WITH ARIA 256 CBC SHA384",
	0xC03E: "TLS DH DSS WITH ARIA 128 CBC SHA256",
	0xC03F: "TLS DH DSS WITH ARIA 256 CBC SHA384",
	0xC040: "TLS DH RSA WITH ARIA 128 CBC SHA256",
	0xC041: "TLS DH RSA WITH ARIA 256 CBC SHA384",
	0xC042: "TLS DHE DSS WITH ARIA 128 CBC SHA256",
	0xC043: "TLS DHE DSS WITH ARIA 256 CBC SHA384",
	0xC044: "TLS DHE RSA WITH ARIA 128 CBC SHA256",
	0xC045: "TLS DHE RSA WITH ARIA 256 CBC SHA384",
	0xC046: "TLS DH anon WITH ARIA 128 CBC SHA256",
	0xC047: "TLS DH anon WITH ARIA 256 CBC SHA384",
	0xC048: "TLS ECDHE ECDSA WITH ARIA 128 CBC SHA256",
	0xC049: "TLS ECDHE ECDSA WITH ARIA 256 CBC SHA384",
	0xC04A: "TLS ECDH ECDSA WITH ARIA 128 CBC SHA256",
	0xC04B: "TLS ECDH ECDSA WITH ARIA 256 CBC SHA384",
	0xC04C: "TLS ECDHE RSA WITH ARIA 128 CBC SHA256",
	0xC04D: "TLS ECDHE RSA WITH ARIA 256 CBC SHA384",
	0xC04E: "TLS ECDH RSA WITH ARIA 128 CBC SHA256",
	0xC04F: "TLS ECDH RSA WITH ARIA 256 CBC SHA384",
	0xC050: "TLS RSA WITH ARIA 128 GCM SHA256",
	0xC051: "TLS RSA WITH ARIA 256 GCM SHA384",
	0xC052: "TLS DHE RSA WITH ARIA 128 GCM SHA256",
	0xC053: "TLS DHE RSA WITH ARIA 256 GCM SHA384",
	0xC054: "TLS DH RSA WITH ARIA 128 GCM SHA256",
	0xC055: "TLS DH RSA WITH ARIA 256 GCM SHA384",
	0xC056: "TLS DHE DSS WITH ARIA 128 GCM SHA256",
	0xC057: "TLS DHE DSS WITH ARIA 256 GCM SHA384",
	0xC058: "TLS DH DSS WITH ARIA 128 GCM SHA256",
	0xC059: "TLS DH DSS WITH ARIA 256 GCM SHA384",
	0xC05A: "TLS DH anon WITH ARIA 128 GCM SHA256",
	0xC05B: "TLS DH anon WITH ARIA 256 GCM SHA384",
	0xC05C: "TLS ECDHE ECDSA WITH ARIA 128 GCM SHA256",
	0xC05D: "TLS ECDHE ECDSA WITH ARIA 256 GCM SHA384",
	0xC05E: "TLS ECDH ECDSA WITH ARIA 128 GCM SHA256",
	0xC05F: "TLS ECDH ECDSA WITH ARIA 256 GCM SHA384",
	0xC060: "TLS ECDHE RSA WITH ARIA 128 GCM SHA256",
	0xC061: "TLS ECDHE RSA WITH ARIA 256 GCM SHA384",
	0xC062: "TLS ECDH RSA WITH ARIA 128 GCM SHA256",
	0xC063: "TLS ECDH RSA WITH ARIA 256 GCM SHA384",
	0xC064: "TLS PSK WITH ARIA 128 CBC SHA256",
	0xC065: "TLS PSK WITH ARIA 256 CBC SHA384",
	0xC066: "TLS DHE PSK WITH ARIA 128 CBC SHA256",
	0xC067: "TLS DHE PSK WITH ARIA 256 CBC SHA384",
	0xC068: "TLS RSA PSK WITH ARIA 128 CBC SHA256",
	0xC069: "TLS RSA PSK WITH ARIA 256 CBC SHA384",
	0xC06A: "TLS PSK WITH ARIA 128 GCM SHA256",
	0xC06B: "TLS PSK WITH ARIA 256 GCM SHA384",
	0xC06C: "TLS DHE PSK WITH ARIA 128 GCM SHA256",
	0xC06D: "TLS DHE PSK WITH ARIA 256 GCM SHA384",
	0xC06E: "TLS RSA PSK WITH ARIA 128 GCM SHA256",
	0xC06F: "TLS RSA PSK WITH ARIA 256 GCM SHA384",
	0xC070: "TLS ECDHE PSK WITH ARIA 128 CBC SHA256",
	0xC071: "TLS ECDHE PSK WITH ARIA 256 CBC SHA384",
	0xC072: "TLS ECDHE ECDSA WITH CAMELLIA 128 CBC SHA256",
	0xC073: "TLS ECDHE ECDSA WITH CAMELLIA 256 CBC SHA384",
	0xC074: "TLS ECDH ECDSA WITH CAMELLIA 128 CBC SHA256",
	0xC075: "TLS ECDH ECDSA WITH CAMELLIA 256 CBC SHA384",
	0xC076: "TLS ECDHE RSA WITH CAMELLIA 128 CBC SHA256",
	0xC077: "TLS ECDHE RSA WITH CAMELLIA 256 CBC SHA384",
	0xC078: "TLS ECDH RSA WITH CAMELLIA 128 CBC SHA256",
	0xC079: "TLS ECDH RSA WITH CAMELLIA 256 CBC SHA384",
	0xC07A: "TLS RSA WITH CAMELLIA 128 GCM SHA256",
	0xC07B: "TLS RSA WITH CAMELLIA 256 GCM SHA384",
	0xC07C: "TLS DHE RSA WITH CAMELLIA 128 GCM SHA256",
	0xC07D: "TLS DHE RSA WITH CAMELLIA 256 GCM SHA384",
	0xC07E: "TLS DH RSA WITH CAMELLIA 128 GCM SHA256",
	0xC07F: "TLS DH RSA WITH CAMELLIA 256 GCM SHA384",
	0xC080: "TLS DHE DSS WITH CAMELLIA 128 GCM SHA256",
	0xC081: "TLS DHE DSS WITH CAMELLIA 256 GCM SHA384",
	0xC082: "TLS DH DSS WITH CAMELLIA 128 GCM SHA256",
	0xC083: "TLS DH DSS WITH CAMELLIA 256 GCM SHA384",
	0xC084: "TLS DH anon WITH CAMELLIA 128 GCM SHA256",
	0xC085: "TLS DH anon WITH CAMELLIA 256 GCM SHA384",
	0xC086: "TLS ECDHE ECDSA WITH CAMELLIA 128 GCM SHA256",
	0xC087: "TLS ECDHE ECDSA WITH CAMELLIA 256 GCM SHA384",
	0xC088: "TLS ECDH ECDSA WITH CAMELLIA 128 GCM SHA256",
	0xC089: "TLS ECDH ECDSA WITH CAMELLIA 256 GCM SHA384",
	0xC08A: "TLS ECDHE RSA WITH CAMELLIA 128 GCM SHA256",
	0xC08B: "TLS ECDHE RSA WITH CAMELLIA 256 GCM SHA384",
	0xC08C: "TLS ECDH RSA WITH CAMELLIA 128 GCM SHA256",
	0xC08D: "TLS ECDH RSA WITH CAMELLIA 256 GCM SHA384",
	0xC08E: "TLS PSK WITH CAMELLIA 128 GCM SHA256",
	0xC08F: "TLS PSK WITH CAMELLIA 256 GCM SHA384",
	0xC090: "TLS DHE PSK WITH CAMELLIA 128 GCM SHA256",
	0xC091: "TLS DHE PSK WITH CAMELLIA 256 GCM SHA384",
	0xC092: "TLS RSA PSK WITH CAMELLIA 128 GCM SHA256",
	0xC093: "TLS RSA PSK WITH CAMELLIA 256 GCM SHA384",
	0xC094: "TLS PSK WITH CAMELLIA 128 CBC SHA256",
	0xC095: "TLS PSK WITH CAMELLIA 256 CBC SHA384",
	0xC096: "TLS DHE PSK WITH CAMELLIA 128 CBC SHA256",
	0xC097: "TLS DHE PSK WITH CAMELLIA 256 CBC SHA384",
	0xC098: "TLS RSA PSK WITH CAMELLIA 128 CBC SHA256",
	0xC099: "TLS RSA PSK WITH CAMELLIA 256 CBC SHA384",
	0xC09A: "TLS ECDHE PSK WITH CAMELLIA 128 CBC SHA256",
	0xC09B: "TLS ECDHE PSK WITH CAMELLIA 256 CBC SHA384",
	0xC09C: "TLS RSA WITH AES 128 CCM",
	0xC09D: "TLS RSA WITH AES 256 CCM",
	0xC09E: "TLS DHE RSA WITH AES 128 CCM",
	0xC09F: "TLS DHE RSA WITH AES 256 CCM",
	0xC0A0: "TLS RSA WITH AES 128 CCM 8",
	0xC0A1: "TLS RSA WITH AES 256 CCM 8",
	0xC0A2: "TLS DHE RSA WITH AES 128 CCM 8",
	0xC0A3: "TLS DHE RSA WITH AES 256 CCM 8",
	0xC0A4: "TLS PSK WITH AES 128 CCM",
	0xC0A5: "TLS PSK WITH AES 256 CCM",
	0xC0A6: "TLS DHE PSK WITH AES 128 CCM",
	0xC0A7: "TLS DHE PSK WITH AES 256 CCM",
	0xC0A8: "TLS PSK WITH AES 128 CCM 8",
	0xC0A9: "TLS PSK WITH AES 256 CCM 8",
	0xC0AA: "TLS PSK DHE WITH AES 128 CCM 8",
	0xC0AB: "TLS PSK DHE WITH AES 256 CCM 8",
	0xC0AC: "TLS ECDHE ECDSA WITH AES 128 CCM",
	0xC0AD: "TLS ECDHE ECDSA WITH AES 256 CCM",
	0xC0AE: "TLS ECDHE ECDSA WITH AES 128 CCM 8",
	0xC0AF: "TLS ECDHE ECDSA WITH AES 256 CCM 8",
	0xC0B0: "TLS ECCPWD WITH AES 128 GCM SHA256",
	0xC0B1: "TLS ECCPWD WITH AES 256 GCM SHA384",
	0xC0B2: "TLS ECCPWD WITH AES 128 CCM SHA256",
	0xC0B3: "TLS ECCPWD WITH AES 256 CCM SHA384",
	0xC0B4: "TLS SHA256 SHA256",
	0xC0B5: "TLS SHA384 SHA384",
	0xC100: "TLS GOSTR341112 256 WITH KUZNYECHIK CTR OMAC",
	0xC101: "TLS GOSTR341112 256 WITH MAGMA CTR OMAC",
	0xC102: "TLS GOSTR341112 256 WITH 28147 CNT IMIT",
	0xC103: "TLS GOSTR341112 256 WITH KUZNYECHIK MGM L",
	0xC104: "TLS GOSTR341112 256 WITH MAGMA MGM L",
	0xC105: "TLS GOSTR341112 256 WITH KUZNYECHIK MGM S",
	0xC106: "TLS GOSTR341112 256 WITH MAGMA MGM S",
	0xCCA8: "TLS ECDHE RSA WITH CHACHA20 POLY1305 SHA256",
	0xCCA9: "TLS ECDHE ECDSA WITH CHACHA20 POLY1305 SHA256",
	0xCCAA: "TLS DHE RSA WITH CHACHA20 POLY1305 SHA256",
	0xCCAB: "TLS PSK WITH CHACHA20 POLY1305 SHA256",
	0xCCAC: "TLS ECDHE PSK WITH CHACHA20 POLY1305 SHA256",
	0xCCAD: "TLS DHE PSK WITH CHACHA20 POLY1305 SHA256",
	0xCCAE: "TLS RSA PSK WITH CHACHA20 POLY1305 SHA256",
	0xD001: "TLS ECDHE PSK WITH AES 128 GCM SHA256",
	0xD002: "TLS ECDHE PSK WITH AES 256 GCM SHA384",
	0xD003: "TLS ECDHE PSK WITH AES 128 CCM 8 SHA256",
	0xD005: "TLS ECDHE PSK WITH AES 128 CCM SHA256",
}

// reverse map of binary TLS Version to string
var tlsVersions = map[uint16]string{
	0x0300: "SSL 3.0",
	0x0301: "TLS 1.0",
	0x0302: "TLS 1.1",
	0x0303: "TLS 1.2",
	0x0304: "TLS 1.3",
}

// CipherSuite returns a string from the map or else just formats the uint16
func CipherSuite(c uint16) string {
	str, ok := cipherSuites[c]
	if !ok {
		return fmt.Sprintf("%04x", c)
	}
	return str
}

// TLSVersion returns a string from the map or else just formats the uint16
func TLSVersion(v uint16) string {
	str, ok := tlsVersions[v]
	if !ok {
		return fmt.Sprintf("%04x", v)
	}
	return str
}
